@@ -8,17 +8,19 @@ https://www.aug.ipp.mpg.de/~git/pyaug/sfread.html
 
 """
 __author__  = 'Giovanni Tardini (Tel. 1898)'
-__version__ = '0.2.9'
-__date__    = '12.10.2021'
+__version__ = '0.3.0'
+__date__    = '13.10.2021'
 
 import sys, logging
 
-fmt = logging.Formatter('[%(asctime)s] %(levelname)s: %(message)s')
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
 hnd = logging.StreamHandler()
 hnd.setFormatter(fmt)
-logging.root.addHandler(hnd)
-logging.root.setLevel(logging.INFO)
-log = logging.getLogger()
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('aug_sfutils')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
 
 from .sfread import *
 from .sf2equ import *
@@ -29,7 +31,7 @@ try:
     from .sfh import *
 except:
     log = logging.getLogger()
-    log.warning('ww and sfh not loaded, SFREAD and EQU available')
+    logger.warning('ww and sfh not loaded, SFREAD and EQU available')
     pass
 
 import encodings.utf_8
