@@ -118,7 +118,7 @@ def ddcshotnr(diag, shot=99999, exp='AUGD'):
 
 
 def previousshot(diag, shot=99999, exp='AUGD'):
-    ddcshotnr(diag, shot=shot, exp=exp)
+    return ddcshotnr(diag, shot=shot, exp=exp)
 
 
 if __name__ == "__main__":
