@@ -31,7 +31,7 @@ obj_name = {1: 'Diagnostic', 2: 'List', 3: 'Device', 4: 'Param_Set', \
             12: 'Loc_Timer', 13: 'Area Base', 14: 'Qualifier', \
             15: 'ModObj', 16: 'Map_Extd', 17: 'Resource'}
 
-cal_type = {1: 'LinCalib'}
+cal_type = {1: 'LinCalib', 3: 'External'}
 
 # Source: /afs/ipp/aug/ads/common/codes/formats
 
