@@ -5,7 +5,15 @@ from . import sfdics, str_byt
 
 n_rel = 8
 
-log = logging.getLogger()
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('sfhread')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
+
 
 def read_sfh(byt_str):
     """
@@ -58,7 +66,7 @@ def read_sfh(byt_str):
             break
 
     tend = time.time()
-    log.debug('Time SFHread: %8.4f' %(tend - tbeg))
+    logger.debug('Time SFHread: %8.4f' %(tend - tbeg))
 
     return sfhead
 
