@@ -2,11 +2,23 @@ import os, datetime, logging
 from struct import unpack
 import numpy as np
 
-from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt
+from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
-log = logging.getLogger()
+fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
+hnd = logging.StreamHandler()
+hnd.setFormatter(fmt)
+hnd.setLevel(level=logging.INFO)
+logger = logging.getLogger('sfread')
+logger.addHandler(hnd)
+logger.setLevel(logging.INFO)
+logger.propagate = False
+
+
+def read_other_sf(*args, **kwargs):
+
+    return SFREAD(*args, **kwargs)
 
 
 def parse_url(url, blen=100):
@@ -26,29 +38,29 @@ def parse_url(url, blen=100):
                 import urllib
                 url_lib = 'urllib'
             except:
-                log.error('No URL lib found, exiting')
+                logger.error('No URL lib found, exiting')
                 return None
-    log.info('URL reading with %s' %url_lib)
+    logger.info('URL reading with %s' %url_lib)
     url_not_found = 'URLs %s not found, exiting' %url
     if url_lib == 'urllib3':
         http = urllib3.PoolManager()
         try:
             tmp = http.request('GET', url)
         except:
-            log.error(url_not_found)
+            logger.error(url_not_found)
             return None
         bshot = tmp.data
     elif url_lib == 'urllib2':
         try:
             bshot = urllib2.urlopen(url).read(blen)
         except:
-            log.exception(url_not_found)
+            logger.exception(url_not_found)
             return None
     elif url_lib == 'urllib':
         try:
             bshot = request.urlopen(url).read()
         except:
-            log.exception(url_not_found)
+            logger.exception(url_not_found)
             return None
 
     return bshot
@@ -69,7 +81,7 @@ def getlastshot():
             page = str_byt.to_str(page)
             idx = page.find("Current shot:")
             if idx < 0:
-                log.warning('Missing substring "Current shot:" in %s, exiting' %url2)
+                logger.warning('Missing substring "Current shot:" in %s, exiting' %url2)
                 return None
             substr = page[idx:idx+30]
             a = substr.find('>')+1
@@ -80,7 +92,7 @@ def getlastshot():
         try:
             nshot = int(sshot)
         except:
-            log.exception('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
+            logger.exception('ERROR sfread.getlastshot: cannot convert string %s to integer' %sshot)
             nshot = None
 
     return nshot
@@ -173,7 +185,7 @@ class SFREAD:
 
             n_args = len(args) 
             if n_args == 0:
-                log.warning('No argument given, need at least diag_name')
+                logger.warning('No argument given, need at least diag_name')
                 return
             if isinstance(args[0], str) and len(args[0].strip()) == 3:
                 diag = args[0].strip()
@@ -186,17 +198,17 @@ class SFREAD:
                     if isinstance(args[1], str) and len(args[1].strip()) == 3:
                         diag = args[1].strip()
             if 'nshot' not in locals(): 
-                log.warning('No argument is a shot number (int), taking last AUG shot')
+                logger.warning('No argument is a shot number (int), taking last AUG shot')
                 nshot = getlastshot()
             if 'diag' not in locals():
                 diag = input('Please enter a diag_name (str(3), no delimiter):\n')
 
             exp = parse_kwargs.parse_kw( ('exp', 'experiment'), kwargs, default='AUGD')
             ed  = parse_kwargs.parse_kw( ('ed', 'edition'), kwargs, default=0)
-
+            logger.debug('%d %s %s %d', nshot, diag, exp, ed)
             self.sfile, self.ed = manage_ed.sf_path(nshot, diag, exp=exp, ed=ed)
             if self.sfile is None:
-                log.error('Shotfile not found')
+                logger.error('Shotfile not found')
                 return
             else:
                 self.shot = nshot
@@ -208,12 +220,12 @@ class SFREAD:
             with open(self.sfile, 'rb') as f:
                 byt_str = f.read(128000)
                 if len(byt_str) < 128:
-                    log.error('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
+                    logger.error('Error: shotfile %s has < 128 bytes, ignored' %(self.sfile))
                     return
                 self.sfh = sfhread.read_sfh(byt_str)
                 self.status = True
         else:
-            log.error('Shotfile %s not found' %self.sfile)
+            logger.error('Shotfile %s not found' %self.sfile)
             return
 
         if self.status:
@@ -299,7 +311,7 @@ class SFREAD:
 
         sfo = self.sfh[obj]
         if sfo.status != 0:
-            log.error('Status of SF object %s is %d' %(obj, sfo.status))
+            logger.error('Status of SF object %s is %d' %(obj, sfo.status))
             return None
         otyp = sfo.obj_type
         if otyp in (6, 7):
@@ -415,8 +427,14 @@ class SFREAD:
             if self.sfh[rel].obj_type == 4:
                 caltyp = str_byt.to_str(sfdics.cal_type[self.sfh[rel].cal_type])
                 if caltyp == 'LinCalib':
-                    log.info('PSet for calib: %s' %rel)
+                    logger.info('PSet for calib: %s' %rel)
                     return self.getparset(rel)
+                elif caltyp == 'External':
+                    diag_ext = self.getparset(rel)['DIAGNAME']
+                    diag_ext = ''.join([str_byt.to_str(x) for x in diag_ext])
+                    shot_ext = libddc.previousshot(diag_ext)
+                    ext = read_other_sf(shot_ext, diag_ext)
+                    return ext.getparset(rel) # same name in external shotfile
         return None
 
 
@@ -442,7 +460,7 @@ class SFREAD:
             meta = type('', (), {})()
 #            meta.phys_unit = sfdics.unit_d[unit]
             meta.data_format = dfmt
-            log.debug(pname, unit, dfmt, n_items)
+            logger.debug(pname, unit, dfmt, n_items)
             status = unpack('>h', buf[j0+14:  j0+16])[0]
             j0 += 16
             if dfmt in sfdics.fmt2len.keys(): # char variable
@@ -464,7 +482,7 @@ class SFREAD:
                 dj0 = 8 * ( (bytlen + 7)//8 )
                 j0 += dj0
 
-            log.debug(pname, data)
+            logger.debug(pname, data)
             par_d[pname] = sfobj.SFOBJ(data, sfho=meta)
 
         return par_d
